<?php

/**
 * Solution Landing Page template.
 * 
 * @package ThemeStarter
 */

?>

<!-- Get Header -->
<?php
// Check if the 'gads' parameter exists in the URL
if (isset($_GET['ad'])) {
    // Load specific header for when 'gads' parameter exists
    get_header('landing');
} else {
    // Load default header
    get_header();
}
?>

<!-- Single Solution -->
<section class="bg-stone-100 py-8 flex items-center">

    <div class="max-w-7xl mx-auto md:grid md:grid-cols-2 gap-8 px-4 items-center">

        <div class="flex-1">

            <h2 class="font-medium"><?= get_field("solution_products_list_subheading")  ?>...</h2>

            <h1 class="font-bold text-3xl md:text-4xl lg:text-5xl"><?= the_title()  ?></h1>

            <ul class="py-4">
                <?php while (have_rows('solution_facts_and_data')) :

                    the_row();
                    $sub_value = get_sub_field('solution_fact'); ?>

                    <li class="flex space-x-4">
                        <i class="bi-check-circle-fill"></i>
                        <p><?php echo $sub_value; ?></p>
                    </li>

                <?php endwhile; ?>
            </ul>


            <div class="mt-4 space-y-2 md:flex md:space-x-2 md:space-y-0">
                <?php get_template_part('template-parts/partials/book-a-meeting-button') ?>
                <?php get_template_part('template-parts/partials/get-a-quote-button') ?>
            </div>

            <ul class="list-disc list-inside py-4">
                <li>No Payment Required</li>
                <li>No Strings Attached</li>
                <li>100% Risk-Free</li>
            </ul>
        </div>

        <div class="flex items-center">
            <div class="bg-white rounded-3xl h-4/5 py-8 px-4 flex flex-col justify-center relative">
                <h3 class="py-2.5 px-8 bg-stone-100 bg-opacity-60 inline-block shadow-md min-w-max mx-auto font-bold text-xl text-center relative z-10">Your <?= str_replace('Development', '', get_the_title()) ?> partner</h3>
                <img src="<?= get_field('solution_image') ?>" alt="">
                <?php
                $args = array(
                    'post_type'      => 'technologies',
                    'posts_per_page' => 4,
                    'orderby'        => 'rand',
                    'order'          => 'ASC',
                    'tax_query'      => array(
                        array(
                            'taxonomy' => 'technologies_category',
                            'field'    => 'slug', // You can use 'id', 'slug', or 'name' depending on how you want to specify the term
                            'terms'    => get_post_field('post_name', get_the_ID()), // Replace 'your-term-slug' with the slug of the term you want to filter by
                        ),
                    ),
                );
                $query = new WP_Query($args);

                if ($query->have_posts()) { ?>
                    <ul class="gap-4 grid grid-cols-4 items-center">
                        <?php
                        $vertical_values = array('lg:top-10', 'lg:top-4/5', 'lg:top-3/4', 'lg:top-2'); // Adjust top values if necessary
                        $horizontal_values = array('lg:-left-10', 'lg:-right-10', 'lg:-left-10', 'lg:-right-16'); // Adjust left values if necessary
                        $index = 0;
                        while ($query->have_posts()) {
                            $query->the_post(); ?>
                            <li class="list-none relative lg:absolute <?= $horizontal_values[$index]; ?> <?= $vertical_values[$index]; ?> lg:p-8 lg:bg-stone-100 lg:shadow-md rounded-full">
                                <img src="<?= get_field('technology_image') ?>" alt="<?= the_title() ?> logo" class="mx-auto max-h-12">
                            </li>
                        <?php
                            $index++;
                        }
                        ?>
                    </ul>
                <?php }
                wp_reset_postdata(); ?>

            </div>
        </div>

    </div>
</section>

<!-- Services -->
<section>

    <div class="max-w-7xl mx-auto py-12 px-4">

        <h2 class="text-center font-bold text-3xl md:text-4xl lg:text-5xl mb-4">
            <?= the_title()  ?> Services
        </h2>
        <h3 class="text-center lg:text-xl">A tailored selection of <?= the_title()  ?> Services we carefully crafted for you.</h3>

        <ul class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8 py-8">

            <?php while (have_rows('solution_services')) :

                the_row(); ?>

                <li class="text-center md:text-left">
                    <img src="<?= get_sub_field('solution_services_icon'); ?>" alt="">
                    <p class="font-medium text-xl"><?= get_sub_field('solution_service_title'); ?></p>
                    <p class="text-lg"><?= get_sub_field('solution_service_description'); ?></p>
                </li>


            <?php endwhile; ?>
        </ul>


    </div>

</section>

<!-- Testimonials -->
<section>

    <div class="mx-auto py-12 px-4">
        <h2 class="text-center font-bold text-3xl md:text-4xl lg:text-5xl mb-4">
            Our Clients, Friends & Professional Partners.
        </h2>

        <?php get_template_part('template-parts/partials/client-grid'); ?>


        <?php get_template_part('template-parts/partials/testimonials-loop'); ?>

    </div>

</section>

<!-- Technologies Ticker -->
<?php get_template_part('template-parts/partials/technologies-ticker'); ?>

<?php if (have_rows('solution_features')) : ?>
    <!-- Features -->
    <section>

        <div class="max-w-7xl mx-auto py-12 px-4">

            <h2 class="text-center font-bold text-3xl md:text-4xl lg:text-5xl mb-4">
                Value filled <?= the_title()  ?>
            </h2>
            <h3 class="text-center lg:text-xl">The benefits you reap with us as your consultant or <?= strtolower(get_the_title())  ?> service provider</h3>

            <ul class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8 py-8">

                <?php while (have_rows('solution_features')) :

                    the_row(); ?>

                    <li class="text-center md:text-left">
                        <div class="flex items-center justify-center space-x-4 mb-4">
                            <img width="15%" src="<?= get_sub_field('solution_feature_icon'); ?>" alt="Solution Feature Icon">
                            <p class="font-medium text-xl"><?= get_sub_field('solution_feature_title'); ?></p>
                        </div>
                        <p class="text-lg text-center"><?= get_sub_field('solution_feature_description'); ?></p>
                    </li>


                <?php endwhile; ?>
            </ul>


        </div>

    </section>
<?php endif; ?>



<!-- Why Us -->
<section class="bg-stone-200">
    <div class="py-10">
        <div class="flex flex-col max-w-7xl mx-auto px-4 relative z-10">
            <div class="text-inherit">
                <div class="mb-12 text-center text-inherit">
                    <p class="font-bold mb-4 text-3xl text-gray-900 tracking-tight sm:text-4xl"><?php _e('Why us?', 'harplabs'); ?></p>
                    <div class="bg-yellow-300 h-0.5 mx-auto w-28"></div>
                </div>


                <!-- Why Us -->
                <div class="gap-2 grid md:grid-cols-2 lg:grid-cols-3 items-stretch justify-center">
                    <?php get_template_part('template-parts/partials/why-us-general'); ?>
                </div>

            </div>
        </div>
    </div>
</section>

<!-- Process -->
<?php get_template_part('template-parts/partials/process-general'); ?>

<!-- FAQs -->
<section>
    <div class="max-w-5xl mx-auto py-12">
        <h3 class="font-bold text-3xl md:text-4xl lg:text-5xl mb-8 text-center">Questions we get asked often.</h3>
        <?php get_template_part('template-parts/partials/faqs-loop') ?>
    </div>
</section>

<!-- Get Started -->
<?php get_template_part('template-parts/partials/get-started-cta') ?>

<!-- Get Footer -->
<?php get_footer(); ?>