class NavControl {
  constructor() {
    this.topBanner = document.getElementById('top-banner');
    this.navbar = document.getElementById('header-nav');
    this.navbarPadding = document.getElementById('header-padder');
    this.contentContainer = document.getElementById('content-container');
    this.toggleMenuBtn = document.getElementById('toggle-nav');
    this.slideOutMenu = document.getElementById('slide-out-menu');
    this.accordions = document.querySelectorAll('#slide-out-menu .accordion');
    this.toggleSearchBtn = document.getElementById('toggle-search');
    this.headerSearch = document.getElementById('header-search');
    this.headerSearchOverlay = document.getElementById('search-overlay');
    this.hoursDropdownToggle = document.getElementById('hours-dropdown-toggle');
    this.todaysBusinessHoursEl = document.getElementById(
      'todays-business-hours'
    );
    this.businessHoursMenu = this.hoursDropdownToggle.nextElementSibling;
    this.init();
  }

  init() {
    // Add event listeners directly, no need to wait for DOMContentLoaded
    // Add a single click event listener to document for handling link clicks and outside clicks
    document.addEventListener('click', (event) => {
      this.handleLinkAndOutsideClick(event);
    });

    window.addEventListener('scroll', this.handleScroll.bind(this));

    // Open and Close the Nav Menu
    this.toggleMenuBtn.addEventListener('click', () => this.toggleNavMenu());

    // Open and Close the Nav Search
    this.toggleSearchBtn.addEventListener('click', () => this.toggleSearch());

    // Delegate click event to handle business hours toggle
    this.hoursDropdownToggle.addEventListener('click', () => {
      this.businessHoursMenu.classList.toggle('hidden');
    });

    document.addEventListener('keyup', (e) => this.keyPressDispatcher(e));

    this.businessHours();
  }

  headerOutOfView() {
    this.navbar.classList.add('out-of-view');
  }

  headerInView() {
    setTimeout(() => {
      this.navbar.classList.add('in-view');
    }, 100);
    // setTimeout(() => {
    //   this.navbar.classList.remove('out-of-view');
    //   this.navbar.classList.remove('in-view');
    // }, 2000);
  }

  handleScroll() {
    var scrollPosition = window.scrollY;

    if (scrollPosition > 0) {
      // Change this value to adjust when the navbar becomes fixed
      this.headerOutOfView();
      this.headerInView();
      this.navbarPadding.style.display = 'block';
      // this.topBanner.classList.remove('open');
      this.navbar.classList.add('fixed');
      // this.navbarPadding.classList.add('open');
      this.topBanner.style.display = 'none';
    } else {
      // this.topBanner.classList.add('open');
      this.topBanner.style.display = 'block';
      this.navbarPadding.style.display = 'none';
      this.navbar.classList.remove('in-view', 'out-of-view', 'fixed');
      // this.navbarPadding.classList.remove('open');
      setTimeout(() => {
        this.navbar.classList.remove('in-view');
      }, 100);
    }
  }

  isSearchOpen() {
    if (this.headerSearch.classList.contains('active')) {
      return true; // Search is open
    } else {
      return false; // Search is not open
    }
  }

  isMenuOpen() {
    if (this.slideOutMenu.classList.contains('active')) {
      return true; // Menu is open
    } else {
      return false; // Menu is not open
    }
  }

  keyPressDispatcher(e) {
    console.log('Key pressed: ', e.keyCode); // Add this line
    if (e.keyCode === 83 && !this.isSearchOpen()) {
      this.toggleSearch();
    }
    if (e.keyCode === 77 && !this.isMenuOpen() && !this.isSearchOpen()) {
      this.toggleNavMenu();
    }

    if (e.keyCode === 27) {
      if (this.isSearchOpen()) {
        this.toggleSearch();
      } else if (this.isMenuOpen()) {
        this.toggleNavMenu();
      }
    }
  }

  handleLinkAndOutsideClick(event) {
    const target = event.target;

    // Handle link clicks
    const link = target.closest('a');
    if (link) {
      if (
        link.href === window.location.href &&
        this.toggleMenuBtn.classList.contains('active')
      ) {
        this.toggleNavMenu();
      }
      return;
    }

    // Handle outside clicks
    const isOutsideMenu =
      !this.toggleMenuBtn.contains(target) &&
      !this.slideOutMenu.contains(target) &&
      !this.toggleSearchBtn.contains(target) &&
      !this.headerSearch.contains(target);
    if (isOutsideMenu) {
      this.toggleMenuBtn.classList.remove('active');
      this.slideOutMenu.classList.remove('open');
      this.removeBodyNoScroll();
    }

    const isOutsideBusinessHoursToggle =
      !this.hoursDropdownToggle.contains(target) &&
      !this.hoursDropdownToggle.classList.contains('hidden');
    if (isOutsideBusinessHoursToggle) {
      this.businessHoursMenu.classList.add('hidden');
    }

    const isOutsideSearch =
      !this.toggleSearchBtn.contains(target) &&
      !this.headerSearch.contains(target) &&
      !this.toggleMenuBtn.contains(target) &&
      !this.slideOutMenu.contains(target);
    if (isOutsideSearch) {
      this.toggleSearchBtn.classList.remove('active');
      this.headerSearch.classList.remove('active');
      this.headerSearchOverlay.classList.remove('active');
      this.removeBodyNoScroll();
    }
  }

  toggleNavMenu() {
    if (this.headerSearch.classList.contains('active')) {
      this.toggleSearch();
    }
    this.toggleMenuBtn.classList.toggle('active');
    this.slideOutMenu.classList.toggle('open');
    document.body.classList.toggle('noScroll');
    this.collapseAllAccordions();
  }

  toggleSearch() {
    if (this.toggleMenuBtn.classList.contains('active')) {
      this.toggleNavMenu();
    }
    this.headerSearch.classList.toggle('active');
    this.headerSearchOverlay.classList.toggle('active');
    this.headerSearch.querySelector('input').focus();
    document.body.classList.toggle('noScroll');

    if (this.headerSearch.classList.contains('active')) {
      this.headerSearch.querySelector('input').value = '';
    }
  }

  collapseAllAccordions() {
    this.accordions.forEach((accordion) => {
      accordion.classList.remove('active');
    });
  }

  removeBodyNoScroll() {
    if (document.body.classList.contains('noScroll')) {
      document.body.classList.remove('noScroll');
    }
  }

  businessHours() {
    const dayOfWeek = new Date().getDay();
    const defaultHours = 'Open Today from 9:00 am - 5:00 pm';
    let todaysBusinessHours;

    switch (dayOfWeek) {
      case 0: // Sunday
      case 6: // Saturday
        todaysBusinessHours = `<span class="text-red-500">We are closed today.</span>`;
        break;
      default: // Monday to Friday
        todaysBusinessHours = `<span class="text-green-500">${defaultHours}</span>`;
        break;
    }

    this.todaysBusinessHoursEl.innerHTML = todaysBusinessHours;
  }
}

export default NavControl;
